/*
/--------------------------------------------------------------------
|
|      $Id: plobject.cpp,v 1.5 2004/09/11 12:41:35 uzadow Exp $
|
|      Copyright (c) 1996-2002 Ulrich von Zadow
|
\--------------------------------------------------------------------
*/

#include "plobject.h"

PLObject::PLObject()
{

}

PLObject::~PLObject()
{

}

void PLObject::AssertValid() const
{
}

/*
/--------------------------------------------------------------------
|
|      $Log: plobject.cpp,v $
|      Revision 1.5  2004/09/11 12:41:35  uzadow
|      removed plstdpch.h
|
|      Revision 1.4  2002/03/31 13:36:42  uzadow
|      Updated copyright.
|
|      Revision 1.3  2001/09/16 20:57:17  uzadow
|      Linux version name prefix changes
|
|      Revision 1.2  2000/05/27 16:34:05  Ulrich von Zadow
|      Linux compatibility changes
|
|      Revision 1.1  2000/01/17 23:45:07  Ulrich von Zadow
|      MFC-Free version.
|
|
\--------------------------------------------------------------------
*/
